Description Usage Arguments Note
set_connection() function is used to establish a connection with authentication
to Cebrap's Brazilian Legislative Database using JDBC. It does so by starting
the appropriate driver and sending login information to Cebrap's MS-SQL Server.
Users can choose which version o Microsoft's JDBC to utilize and also have the
option to save authentication info in the system path for improved security.
1 | set_connection(login = NULL, password = NULL, driver = NULL, verbose = TRUE)
|
login |
User login |
password |
User password |
driver |
A
|
verbose |
Should the function display messages? Defaults to |
To use this and other functions from cebrapdata, users must have rJava
and Java JDK installed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.